ElementOfListPbx class

Inheritance

Constructors

ElementOfListPbx(String value, {String? comment})

Properties

comment String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

childrenToString(List<NamedComponent> children, {int indentLevel = 0, bool removeN = false}) String
inherited
copyWith({String? value, String? comment}) ElementOfListPbx
override
formatOutput(String output) String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({int indentLevel = 0, bool removeN = false}) String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited