MapPbx class
- Inheritance
-
- Object
- PbxprojComponent
- NamedComponent
- MapPbx
Constructors
Properties
-
childrenList
→ List<
NamedComponent> -
no setterinherited
-
childrenMap
→ HashMap<
String, NamedComponent> -
no setterinherited
- comment → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInline ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → String
-
finalinherited
Methods
-
add(
NamedComponent component) → void -
addis a method that adds a new NamedComponent to the list of children and updates the mapping of children by associating the component's UUID with the component itself.inherited -
childrenToString(
List< NamedComponent> children, {int indentLevel = 0, bool removeN = false}) → String -
inherited
-
copyWith(
{String? uuid, List< NamedComponent> ? children, String? comment, bool? isInline}) → MapPbx -
override
-
find<
T extends NamedComponent> (String key) → T? -
The universal
findmethod takes a String key and returns an instance of typeTthat extends NamedComponent, ornullif not found.inherited -
findComment<
T extends NamedComponent> (String comment) → T? -
findCommentis a method that searches for a component of typeTthat extends NamedComponent based on a givencommentstring. It returns the found component or null if not found.inherited -
formatOutput(
String output) → String -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String uuid) → void -
removeis a method that removes a NamedComponent from the list of children based on the component's UUID. It also removes the mapping of the component from the children map.inherited -
replaceOrAdd(
NamedComponent component) → void -
replaceOrAddreplaces an existing NamedComponent in the list of children with a new component if it already exists, or adds a new component to the list.inherited -
toString(
{int indentLevel = 0, bool removeN = false}) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → NamedComponent? -
The [] operator allows accessing a NamedComponent from the list of children
based on its UUID. Returns the corresponding NamedComponent if found, or null.
inherited