NamedComponent class abstract

Inheritance
Implementers

Constructors

NamedComponent({required String uuid, String? comment})

Properties

comment String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid String
final

Methods

childrenToString(List<NamedComponent> children, {int indentLevel = 0, bool removeN = false}) String
inherited
copyWith() PbxprojComponent
inherited
formatOutput(String output) String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({int indentLevel = 0, bool removeN = false}) String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited