PbxprojComponent class abstract

Implementers

Constructors

PbxprojComponent()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

childrenToString(List<NamedComponent> children, {int indentLevel = 0, bool removeN = false}) String
copyWith() PbxprojComponent
formatOutput(String output) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({int indentLevel = 0, bool removeN = false}) String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited