add method

void add(
  1. NamedComponent component
)
inherited

add is a method that adds a new NamedComponent to the list of children and updates the mapping of children by associating the component's UUID with the component itself.

Implementation

void add(NamedComponent component) {
  childrenList.add(component);
  childrenMap[component.uuid] = component;
}