ListPbx class
- Inheritance
-
- Object
- PbxprojComponent
- NamedComponent
- ListPbx
Constructors
-
ListPbx(String uuid, List<
ElementOfListPbx> children, {String? comment})
Properties
- comment → String?
-
finalinherited
- first → ElementOfListPbx
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- isNotEmpty → bool
-
no setter
-
iterator
→ Iterator<
ElementOfListPbx> -
no setter
- last → ElementOfListPbx
-
no setter
- length → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → String
-
finalinherited
Methods
-
add(
ElementOfListPbx element) → void -
any(
bool test(ElementOfListPbx e)) → bool -
childrenToString(
List< NamedComponent> children, {int indentLevel = 0, bool removeN = false}) → String -
inherited
-
copyWith(
{String? uuid, List< ElementOfListPbx> ? children, String? comment}) → ListPbx -
override
-
formatOutput(
String output) → String -
inherited
-
indexOf(
ElementOfListPbx element, [int start = 0]) → int -
indexWhere(
bool test(ElementOfListPbx e), [int start = 0]) → int -
insert(
int index, ElementOfListPbx element) → void -
insertAll(
int index, Iterable< ElementOfListPbx> iterable) → void -
map<
T> (T toElement(ElementOfListPbx e)) → Iterable< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
Object? value) → void -
removeAt(
int index) → ElementOfListPbx -
removeLast(
) → ElementOfListPbx -
toList(
) → List< ElementOfListPbx> -
toString(
{int indentLevel = 0, bool removeN = false}) → String -
A string representation of this object.
override
-
where(
bool test(ElementOfListPbx e)) → Iterable< ElementOfListPbx>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → ElementOfListPbx